import { closeConnection } from './closeConnection';
import { sendResponse } from './sendResponse';
export class WsApi {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    routeHandlers = {
        '$connect': () => Promise.resolve(),
        '$disconnect': () => Promise.resolve(),
    };
    addRouteHandler(routeHandler) {
        this.routeHandlers[routeHandler.route.action] = routeHandler.requestHandler;
        return this;
    }
    async handleRequest(event) {
        const { body } = event;
        const { connectionId, domainName, stage, routeKey: action } = event.requestContext;
        if (!action)
            throw 'No routeKey/action';
        if (!connectionId)
            throw 'No connectionId';
        if (!domainName)
            throw 'No domainName';
        if (!body && !['$connect', '$disconnect'].includes(action))
            throw 'No body';
        const endpoint = `https://${domainName}/${stage}`;
        const connection = { endpoint, connectionId };
        const requestHandler = this.routeHandlers[action];
        if (!requestHandler) {
            await closeConnection(connection);
            throw `No requestHandler found for action ${action}`;
        }
        await requestHandler(body && JSON.parse(body), {
            connection,
            sendResponse: async (response) => await sendResponse(connection, response),
            closeConnection: async () => await closeConnection(connection),
        });
        return {
            statusCode: 200,
            body: '',
        };
    }
}
//# sourceMappingURL=WsApi.js.map